summaryrefslogtreecommitdiffstats
path: root/sys/netgraph/ng_pppoe.h
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2002-02-20 15:51:11 +0000
committerbrian <brian@FreeBSD.org>2002-02-20 15:51:11 +0000
commitc53e73d628ce85e58c9e9036af405ce5349880a3 (patch)
tree4a515e4fe646b0327f06d6c4b11ef6dc67692b18 /sys/netgraph/ng_pppoe.h
parentad827f33f7f88bfb8412c89adcc8a18907121f43 (diff)
downloadFreeBSD-src-c53e73d628ce85e58c9e9036af405ce5349880a3.zip
FreeBSD-src-c53e73d628ce85e58c9e9036af405ce5349880a3.tar.gz
Send a NGM_PPPOE_ACNAME message to userland when a node is connected.
Submitted by: Andre Albsmeier <andre@albsmeier.net> Shuffled about by: brian Approved by: julian
Diffstat (limited to 'sys/netgraph/ng_pppoe.h')
-rw-r--r--sys/netgraph/ng_pppoe.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sys/netgraph/ng_pppoe.h b/sys/netgraph/ng_pppoe.h
index b841d85..826d4b0 100644
--- a/sys/netgraph/ng_pppoe.h
+++ b/sys/netgraph/ng_pppoe.h
@@ -64,7 +64,7 @@
/**********************************************************************
* Netgraph commands understood by this node type.
* FAIL, SUCCESS and CLOSE are sent by the node rather than received.
********************************************************************/
enum cmd {
NGM_PPPOE_SET_FLAG = 1,
@@ -75,6 +75,7 @@ enum cmd {
NGM_PPPOE_FAIL = 6, /* State machine could not connect */
NGM_PPPOE_CLOSE = 7, /* Session closed down */
NGM_PPPOE_SERVICE = 8, /* additional Service to advertise (in PADO) */
+ NGM_PPPOE_ACNAME = 9, /* AC_NAME for informational purposes */
NGM_PPPOE_GET_STATUS
};
OpenPOWER on IntegriCloud
@@ -64,7 +64,7 @@
/**********************************************************************
* Netgraph commands understood by this node type.
- * FAIL, SUCCESS and CLOSE are sent by the node rather than received.
+ * FAIL, SUCCESS, CLOSE and ACNAME are sent by the node rather than received.
********************************************************************/
enum cmd {